==> cramr_ui_lib-1.0.16.tar.gz: test/routes/verb_indicative_study_route_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

//TODO: introduce mocking
void main() {
  testWidgets('Test the instantiation based on the cover mode enum',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
            'fr', 'translation', _mode, _tense);
        return model;
      },
      child: VerbIndicativeStudyCoverModeRoute(
          SettingsController(SettingsService(prefs), ThemeMode.dark, prefs,
              NotificationService()),
          key: UniqueKey()),
    ));
    Finder routeFinder =
        find.byKey(const Key('study_scroll_$_randomInfinitive'));
    expect(routeFinder, findsOneWidget);
  });
}

==> cramr_ui_lib-2.0.1.tar.gz: test/routes/verb_indicative_study_route_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/settings/client_context.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

//TODO: introduce mocking
void main() {
  testWidgets('Test the instantiation based on the cover mode enum',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
            'fr', 'translation', _mode, _tense);
        return model;
      },
      child: VerbIndicativeStudyCoverModeRoute(
          SettingsController(
              SettingsService(prefs),
              ThemeMode.dark,
              prefs,
              NotificationService(),
              ClientContext(ClientApp.verbomatiqueSecondaire)),
          key: UniqueKey()),
    ));
    Finder routeFinder =
        find.byKey(const Key('study_scroll_$_randomInfinitive'));
    expect(routeFinder, findsOneWidget);
  });
}
